[![Build Status](https://travis-ci.org/Terralego/django-geostore.svg?branch=master)](https://travis-ci.org/Terralego/django-geostore/)
[![codecov](https://codecov.io/gh/Terralego/django-geostore/branch/master/graph/badge.svg)](https://codecov.io/gh/Terralego/django-geostore)
[![Maintainability](https://api.codeclimate.com/v1/badges/74b0d8430ff982633ee7/maintainability)](https://codeclimate.com/github/Terralego/django-geostore/maintainability)
[![Documentation Status](https://readthedocs.org/projects/django-geostore/badge/?version=latest)](https://django-geostore.readthedocs.io/en/latest/?badge=latest)

![Python Version](https://img.shields.io/badge/python-%3E%3D%203.6-blue.svg)
![Django Version](https://img.shields.io/badge/django-%3E%3D%202.1%2C<3.0-blue.svg)
![Rest Version](https://img.shields.io/badge/django--rest--framework-%3E%3D%203.8.0-blue)

# django-geostore

Dynamic geo data store with json schema validation

## Requirements

* Postgresql 10+
* PostGIS 2.4+
* Optionnal: PgRouting 2.5+
